@@ -1,7 +1,5 @@
 #!/usr/bin/env python
-from __future__ import (absolute_import, division,
-                        print_function, unicode_literals)
-
+from __future__ import absolute_import, division, print_function, unicode_literals
 import sys
 
 from .config import get_config, configure_job
